pocketpose.models.decoder.base_decoder - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.models.decoder.base_decoder`

## Module Contents

### Classes

`Decoder` | Base class for all decoders.

class pocketpose.models.decoder.base_decoder.Decoder

  Bases: `abc.ABC`

  Base class for all decoders.

  Decoders are used to decode the prediction of pose models into a keypoint list in the image coordinate system. The keypoint list is a list of tuples (x, y, score) where x and y are the coordinates and score is the prediction confidence.

  All decoders must implement the decode method. Each model has a corresponding decoder, and the decode method is automatically called when the model is used for prediction.

  abstract decode(x, image_size)